@@ -9,9 +9,12 @@ import re
 
 # Use core json for 2.6+, simplejson for <=2.5
 try:
-    import json
+    import simplejson as json # Prefer this as it is faster
 except ImportError: # pragma: no cover
-    import simplejson as json
+    try:
+        import json
+    except ImportError:
+        raise ImportError("Could not find any JSON module to import - please install simplejson to continue")
 
 # Local intermine imports
 from intermine.query import Query, Template
@@ -639,12 +642,15 @@ class JSONIterator(object):
         self.header = ""
         self.footer = ""
         self.parse_header()
+        self._is_finished = False
     
     def __iter__(self):
         return self
 
     def next(self):
         """Returns a parsed row of data"""
+        if self._is_finished:
+            raise StopIteration
         return self.get_next_row_from_connection()
 
     def parse_header(self):
@@ -705,6 +711,7 @@ class JSONIterator(object):
             raise WebserviceError("Connection interrupted")
 
         if next_row is None:
+            self._is_finished = True
             raise StopIteration
         else:
             return next_row
